==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/DownloadingMultiScaleImageEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DownloadingMultiScaleImageEventArgsDescription } from "./DownloadingMultiScaleImageEventArgsDescription";
/**
 * @hidden
 */
var DownloadingMultiScaleImageEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(DownloadingMultiScaleImageEventArgsDescriptionMetadata, _super);
    function DownloadingMultiScaleImageEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DownloadingMultiScaleImageEventArgsDescriptionMetadata.b = function (a) {
        if (DownloadingMultiScaleImageEventArgsDescriptionMetadata.a == null) {
            DownloadingMultiScaleImageEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DownloadingMultiScaleImageEventArgsDescriptionMetadata.c(DownloadingMultiScaleImageEventArgsDescriptionMetadata.a);
        }
        if (a.j(DownloadingMultiScaleImageEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(DownloadingMultiScaleImageEventArgsDescriptionMetadata.a);
    };
    DownloadingMultiScaleImageEventArgsDescriptionMetadata.c = function (a) {
        a.item("Uri", "String");
    };
    DownloadingMultiScaleImageEventArgsDescriptionMetadata.d = function (a) {
        DownloadingMultiScaleImageEventArgsDescriptionMetadata.b(a);
        a.aa("DownloadingMultiScaleImageEventArgs", function () { return new DownloadingMultiScaleImageEventArgsDescription(); });
        a.z("DownloadingMultiScaleImageEventArgs", DownloadingMultiScaleImageEventArgsDescriptionMetadata.a);
    };
    DownloadingMultiScaleImageEventArgsDescriptionMetadata.$t = markType(DownloadingMultiScaleImageEventArgsDescriptionMetadata, 'DownloadingMultiScaleImageEventArgsDescriptionMetadata');
    DownloadingMultiScaleImageEventArgsDescriptionMetadata.a = null;
    return DownloadingMultiScaleImageEventArgsDescriptionMetadata;
}(Base));
export { DownloadingMultiScaleImageEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/DownloadingMultiScaleImageEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DownloadingMultiScaleImageEventArgsDescription } from "./DownloadingMultiScaleImageEventArgsDescription";
/**
 * @hidden
 */
var DownloadingMultiScaleImageEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(DownloadingMultiScaleImageEventArgsDescriptionMetadata, _super);
    function DownloadingMultiScaleImageEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DownloadingMultiScaleImageEventArgsDescriptionMetadata.b = function (a) {
        if (DownloadingMultiScaleImageEventArgsDescriptionMetadata.a == null) {
            DownloadingMultiScaleImageEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DownloadingMultiScaleImageEventArgsDescriptionMetadata.c(DownloadingMultiScaleImageEventArgsDescriptionMetadata.a);
        }
        if (a.k(DownloadingMultiScaleImageEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(DownloadingMultiScaleImageEventArgsDescriptionMetadata.a);
    };
    DownloadingMultiScaleImageEventArgsDescriptionMetadata.c = function (a) {
        a.item("Uri", "String");
    };
    DownloadingMultiScaleImageEventArgsDescriptionMetadata.d = function (a) {
        DownloadingMultiScaleImageEventArgsDescriptionMetadata.b(a);
        a.ac("DownloadingMultiScaleImageEventArgs", function () { return new DownloadingMultiScaleImageEventArgsDescription(); });
        a.ab("DownloadingMultiScaleImageEventArgs", DownloadingMultiScaleImageEventArgsDescriptionMetadata.a);
    };
    DownloadingMultiScaleImageEventArgsDescriptionMetadata.$t = markType(DownloadingMultiScaleImageEventArgsDescriptionMetadata, 'DownloadingMultiScaleImageEventArgsDescriptionMetadata');
    DownloadingMultiScaleImageEventArgsDescriptionMetadata.a = null;
    return DownloadingMultiScaleImageEventArgsDescriptionMetadata;
}(Base));
export { DownloadingMultiScaleImageEventArgsDescriptionMetadata };
